/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.ratifier;

import com.openexchange.exception.OXException;

/**
 * {@link GuardRatifierService}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public interface GuardRatifierService {

    /**
     * Validates the specified e-mail address
     *
     * @param email The e-mail to validate
     * @throws OXException in case of an validation error
     */
    void validate(String email) throws OXException;

    /**
     * Normalise the specified string. Primarily for PGP in-line.
     *
     * @param data The data to normalise
     * @return The normalised string
     */
    String normalise(String data) throws OXException;

    /**
     * Verifies the ipAddress string is a valid IP
     * @param ipAddress
     * @return ipAddress if valid, null if not
     */
    String verifyIPAddress (String ipAddress);

    /**
     * Validates that the ipAddress string is a valid remote IP address
     * @param ipAddress
     * @return ipAddress if valid, null if not or local IP address
     */
    String verifyRemoteIP(String ipAddress);

    /**
     * Verify that that a date is within a reasonable time frame.  Must be within the last 10 years,
     * and not more than 1 day in the future (to allow for clock async)
     * @throws OXException
     */
    void validateReasonablePastDate(Long ticks) throws OXException;

    /**
     * @param email
     * @return true if valid email address
     */
    boolean isValid(String email);
}
